@@ -19,11 +19,13 @@ typedef struct {
 	char	*ofName,
 		*ofDescription;
 	
-	int (*ofFunction)(FILE *, t_stats *, t_config *);
+	int (*ofInit)(t_config *);
+	int (*ofFunction)(FILE *, t_stats *, t_fisgconfig *);
 } t_outformat;
 
 
 extern const t_outformat	outputFormats[];
 extern const int		nOutputFormats;
 
+
 #endif /* _OUT_FORMATS_H */
