@@ -1,26 +1,28 @@
 /*
  * Simple commandline argument processing function
  * Programmed and designed by Matti 'ccr' Hamalainen
- * (C) Copyright 2002-2003 Tecnic Software productions (TNSP)
+ * (C) Copyright 2002-2004 Tecnic Software productions (TNSP)
  *
  * Please read file 'COPYING' for information on license and distribution.
  */
 #ifndef _TH_ARGS
 #define _TH_ARGS
+#include <stdio.h>
 
 typedef struct {
-	char *shortArg;
-	char *longArg;
-	char *argDesc;
+	int optID;
+	char shortOpt;
+	char *longOpt;
+	char *optDesc;
 	int hasArg;
-} t_arg;
+} t_opt;
 
 
 void th_processArgs(int argc, char *argv[],
-	t_arg argList[], int argListN,
+	t_opt argList[], int argListN,
 	void (*handleOpt)(int, char *, char *),
 	void (*handleFile)(char *));
 
-void th_showHelp(t_arg argList[], int argListN);
+void th_showHelp(FILE *, t_opt optList[], int optListN, char *, char *);
 
 #endif /* _TH_ARGS */
