@@ -52,6 +52,6 @@ for ICHANNEL in $MCHANNELS; do
 	else
 	COPT=""
 	fi
-	$MFISG -c $MCONFIG $COPT $MLOGPATH/ -o "$MHTMLPATH/$MHTMLPREFIX$INAME$MHTMLSUFFIX"
+	$MFISG -c $MCONFIG $COPT -f irssi $MLOGPATH/ -o "$MHTMLPATH/$MHTMLPREFIX$INAME$MHTMLSUFFIX"
 done
 
